{% load pin_tags%}
{% load daddy_avatar%}
{% for noti in notif %}
<div class="notif">
	{% if noti.type == 1 %}
		<span>
			<a href="{% url pin-user noti.sender.id%}">
				<img src="{{noti.sender.email|daddy_avatar:30}}" style="display: inline;" > 
			</a>
		</span> از 
		{% if noti.post.text.strip %}
			<span><a href="{% url pin-item noti.post.id %}">{{noti.post.text|truncatewords:30}}</a></span>
		{% else %}
			<span><a href="{% url pin-item noti.post.id %}">{{noti.post.id}}</a></span>
		{% endif %}
	    خوشش اومد.<br>
	{% endif %}
	
	{% if noti.type == 2 %}
		<span>
			<a href="{% url pin-user noti.sender.id%}">
				<img src="{{noti.sender.email|daddy_avatar:30}}" style="display: inline;" > 
			</a>
		</span> در 
		{% if noti.post.text.strip %}
			<span><a href="{% url pin-item noti.post.id %}">{{noti.post.text|truncatewords:30}}</a></span>
		{% else %}
			<span><a href="{% url pin-item noti.post.id %}">{{noti.post.id}}</a></span>
		{% endif %}
	    نظر داد.<br>
	{% endif %}
	
</div>
{% endfor %}
