body{
	direction: rtl;
	text-align: right;
	/*background: url('../img/paper.jpg') repeat ;*/
	background-color: #CDCDCD!important;
}
#feed-ul{
	list-style: none;
	margin:0 auto;
	padding:0;
	width: 91%;
}

#feed-ul-v2{
	list-style: none;
	margin:0 auto;
	padding:0;
	width: 100%;
}

#feed-ul-item{
	width: 600px;
	margin: 0 auto;
	list-style: none;
}

.feed-inner-item{
	width:603px!important;
	border-top:2px solid #0282B8!important;
}

#feed-ul .feed-item{
	width : 192px;
	-webkit-box-shadow: 0 1px 3px rgba(34,25,25,0.4);
	overflow: hidden;
	/*border-top: 2px solid #C00;*/
	box-shadow: 0 2px 4px #86898C;
	float: right;
	/*padding: 15px 15px 30px;*/
	background: #FFF;
}
#feed-ul-v2 .feed-item{
	/*width : 192px;*/
	-webkit-box-shadow: 0 1px 3px rgba(34,25,25,0.4);
	overflow: hidden;
	border-top: 2px solid #C00;
	box-shadow: 0 2px 4px #86898C;
	/*float: right;*/
	padding: 5px 5px 5px;
	background: #FFF;
	margin: 8px 0 2px 0;
}


#feed-ul .feed-inner{
	/*width : ;*/
	/*-webkit-box-shadow: 0 1px 3px rgba(34,25,25,0.4);*/
	overflow: hidden;
}

#feed-ul img{
	display: block;
	padding-bottom: 5px;
}
.feed-actions{
	right:0;
	width:100%;
	top:-40px;
	position:absolute;
	font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
	padding-bottom: 5px;
	text-align: center;
}
.pin-item-top{
	padding:5px;
}
.feed-description{
	font-family:Tahoma,Arial, Helvetica, sans-serif;
	font-size:.8em;
	text-align: justify;
	line-height: 18px;
}

.feed-card {
	background-color: white;
	border-top: 2px solid #0282B8;
	box-shadow: 0 2px 4px #86898C;
	margin-bottom: 15px;
	padding: 15px;
}
.feed-item {
	/*padding: 5px;*/
	margin: 7px;
	font-family: 'afsfont';
	font-weight: normal;
}
.feed-item .row-fluid{
	margin: 5px;
}
.feed-item-title {
	font-size: 16px;
	margin: 0px 8px;
	color: #069;
	display: block;
}
.feed-sub{
	font-family: Tahoma;
	cursor: pointer;
}
a {
	text-decoration: none;
	color: #4F4F4F;
	font-weight: normal;
	font-family: 'afsfont';
}
.feed-item-desc {
	border-right: 5px solid #E7ECEF;
	color: #5B5F61;
	font-size: 11px;
	line-height: 18px;
	margin: 10px 0 0 0;
	overflow: hidden;
	padding-right: 15px;
	text-align: justify;
	font-family: Tahoma;
	margin-left: 15px;
}
.feed-item-bottom {
	background: #F7F5F6;
	border-top: 1px solid gainsboro;
	min-height: 25px;
	padding: 5px 15px 10px;
}

.feed-item p {
    font-family: tahoma;
    font-size: 8.9pt;
    line-height:18px;
    padding:5px;
}

#comments{
	list-style: none;
}

.comment_box {
border-top: 1px solid #E7ECEF;
padding: 15px 0;
}

.comment_box .comment {
border-right: 3px solid #BBB;
min-height: 35px;
padding: 5px 10px;
position: relative;
}

.comment .comment_side {
float: right;
width: 40px;
}

.loading{
	margin: 10px;
	text-align: center;
	display: none;
}

.img-block{
	background: #F2F4F8;
}

#google-oauth{
	background: #fff url(../img/openid-logos.png); background-position: -1px -1px;
	width: 100px;
	height: 60px;
	border: 2px solid #DDD;
	border-right: 2px solid #CCC;
	border-bottom: 2px solid #CCC;
}

#yahoo-oauth{
	background: #fff url(../img/openid-logos.png); background-position: -1px -63px;
	width: 100px;
	height: 60px;
	border: 2px solid #DDD;
	border-right: 2px solid #CCC;
	border-bottom: 2px solid #CCC;
}

#mask {
	display: none;
	background: #000; 
	position: fixed; left: 0; top: 0; 
	z-index: 10;
	width: 100%; height: 100%;
	opacity: 0.8;
	z-index: 999;
}

.reportBox{
	display : none;
	background: #333;
	padding: 10px; 	
	border: 2px solid #ddd;
	float: left;
	font-size: 1.2em;
	position: fixed;
	top: 50%; left: 50%;
	z-index: 99999;
	box-shadow: 0px 0px 20px #999; /* CSS3 */
        -moz-box-shadow: 0px 0px 20px #999; /* Firefox */
        -webkit-box-shadow: 0px 0px 20px #999; /* Safari, Chrome */
	border-radius:3px 3px 3px 3px;
        -moz-border-radius: 3px; /* Firefox */
        -webkit-border-radius: 3px; /* Safari, Chrome */
}

.qq-uploader {
	position: relative;
	width: 100%;
}
.qq-upload-button {
	display: block;
	/*or inline-block*/
	width: 105px;
	padding: 7px 0;
	text-align: center;
	background: #880000;
	border-bottom: 1px solid #DDD;
	color: #FFF;
}
.qq-upload-button-hover {
	background: #CC0000;
}
.qq-upload-button-focus {
	outline: 1px dotted #000000;
}
.qq-upload-drop-area, .qq-upload-extra-drop-area {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	min-height: 30px;
	z-index: 2;
	background: #FF9797;
	text-align: center;
}
.qq-upload-drop-area span {
	display: block;
	position: absolute;
	top: 50%;
	width: 100%;
	margin-top: -8px;
	font-size: 16px;
}
.qq-upload-extra-drop-area {
	position: relative;
	margin-top: 50px;
	font-size: 16px;
	padding-top: 30px;
	height: 20px;
	min-height: 40px;
}
.qq-upload-drop-area-active {
	background: #FF7171;
}
.qq-upload-list {
	margin: 0;
	padding: 0;
	list-style: none;
}
.qq-upload-list li {
	margin: 0;
	padding: 9px;
	line-height: 15px;
	font-size: 16px;
	background-color: #FFF0BD;
}
.qq-upload-file, .qq-upload-spinner, .qq-upload-size, .qq-upload-cancel, .qq-upload-failed-text, .qq-upload-finished {
	margin-right: 12px;
}
.qq-upload-file {
}
.qq-upload-spinner {
	display: inline-block;
	background: url("../img/loading.gif");
	width: 15px;
	height: 15px;
	vertical-align: text-bottom;
}
.qq-upload-finished {
    display:none;
    width:15px;
    height:15px;
    vertical-align:text-bottom;
}
.qq-upload-size, .qq-upload-cancel {
	font-size: 12px;
	font-weight: normal;
}
.qq-upload-failed-text {
	display: none;
}
.qq-upload-failed-icon {
    display:none;
    width:15px;
    height:15px;
    vertical-align:text-bottom;
}
.qq-upload-fail .qq-upload-failed-text {
	display: inline;
}
.qq-upload-list li.qq-upload-success {
	background-color: #5DA30C;
	color: #FFFFFF;
}
.qq-upload-list li.qq-upload-fail {
	background-color: #D60000;
	color: #FFFFFF;
}

#ScrollToTop {
right: 15px;
bottom: -10px;
width: 40px;
padding: 20px 10px 30px;
-moz-transition: bottom 250ms ease-in-out;
-webkit-transition: bottom 250ms ease-in-out;
}

.Button.Indicator {
border-width: 0;
-moz-box-shadow: 0 0 #fff, 0 1px 3px rgba(34,25,25,0.5);
-webkit-box-shadow: 0 0 #fff, 0 1px 3px rgba(34,25,25,0.5);
box-shadow: 0 0 #fff, 0 1px 3px rgba(34,25,25,0.5);
display: block;
font-size: 15px;
text-align: center;
position: fixed;
z-index: 4;
}

.Button.WhiteButton, .repin_memo_on .pin:hover .actions .repin_link {
background-color: #F0EDED;
background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#FDFAFB), to(#F0EDED), color-stop(.5,#F9F7F7),color-stop(.5,#F6F3F4));
background-image: -moz-linear-gradient(top, #FDFAFB, #F9F7F7 50%, #F6F3F4 50%, #F0EDED);
background-image: -o-linear-gradient(top, #FDFAFB, #F9F7F7 50%, #F6F3F4 50%, #F0EDED);
background-image: -webkit-linear-gradient(top, #FDFAFB, #F9F7F7 50%, #F6F3F4 50%, #F0EDED);
border-color: #BBB;
color: #524D4D;
filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fdfafb', endColorstr='#f0eded');
text-shadow: 0 1px rgba(255, 255, 255, 0.9);
}

.Button {
border: 1px solid transparent;
-moz-border-radius: .3em;
-webkit-border-radius: .3em;
border-radius: .3em;
-moz-box-shadow: 0 1px rgba(255,255,255,0.8), inset 0 1px rgba(255,255,255,0.35);
-webkit-box-shadow: 0 1px rgba(255,255,255,0.8), inset 0 1px rgba(255,255,255,0.35);
box-shadow: 0 1px rgba(255,255,255,0.8), inset 0 1px rgba(255,255,255,0.35);
cursor: pointer;
display: inline-block;
font-family: "helvetica neue",arial,sans-serif;
font-weight: bold;
line-height: 1em;
margin: 0;
padding: .45em .825em .45em;
text-align: center;
-moz-transition: all .05s ease-in-out;
-o-transition: all .05s ease-in-out;
-webkit-transition: all .05s ease-in-out;
}

.corner-stamp {
width: 280px;
height: 340px;
padding: 10px;
margin: 10px;
/*float: right;*/
background: red;
color: white;
-webkit-border-radius: 5px;
-moz-border-radius: 5px;
border-radius: 5px;
}

#profile .FixedContainer {
width: 934px;
margin: 10px auto;
}

.ProfileInfo {
height: 160px;
width: 698px;
position: relative;
}

.ProfilePanel {
/*float: righ;*/
background: white;
box-shadow: 0 1px 3px rgba(34,25,25,0.5);
-moz-box-shadow: 0 1px 3px rgba(34,25,25,0.5);
-webkit-box-shadow: 0 1px 3px rgba(34,25,25,0.5);
}

.ProfileInfo .ProfileImage {
height: 165px;
float: right;
max-width: 160px;
overflow: hidden;
}

.ProfileInfo .content {
margin-right: 180px;
padding-left: 15px;
padding-top: 5px;
}

.ProfileInfo h1 {
color: #534F4F;
margin: 15px 0 10px 0;
font-size: 30px;
white-space: nowrap;
overflow: hidden;
}

.tags{
	list-style: none;
}
.tags li{
	display: inline;
	/*background: #F2F4F8;*/
	margin: 5px;
	padding: 5px;
}
.tags a{
	font-size:15px;
	font-weight: normal;
	padding: 5px;
}

.notif{
	border-bottom: 1px solid #DADADA;
	clear: both;
	margin-bottom: 10px;
	padding-bottom: 10px;
}

.profile-name{
	font-family: 'afsFont';
	color: #666;
	font-size: 25px;
	margin: 2px 0 5px 0;
	display:block;
}

.sites-nav {
	font-size: 20px;
	text-align: right;
	border-radius: 5px;
	direction: rtl;
	background-color: rgba(255, 255, 255, 0.4);
	box-shadow: 0px 0px 3px rgba(119, 119, 119, .5);
	padding-top: 10px;
	padding-bottom: 10px;
}